pub fn resolve_layer(caps: &Capabilities) -> SandboxLayerExpand description
Pick the strongest enforcement layer the host supports for these
capabilities. Always returns at least SandboxLayer::Lightweight.
pub fn resolve_layer(caps: &Capabilities) -> SandboxLayerPick the strongest enforcement layer the host supports for these
capabilities. Always returns at least SandboxLayer::Lightweight.